@@ -11,6 +11,8 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import string
+
 import pretend
 import pytest
 
@@ -110,6 +112,28 @@ def test_package_signed_name_is_correct():
     assert package.signed_filename == (filename + ".asc")
 
 
+@pytest.mark.parametrize(
+    "pkg_name,expected_name",
+    [
+        (string.ascii_letters, string.ascii_letters),
+        (string.digits, string.digits),
+        (string.punctuation, "-.-"),
+        ("mosaik.SimConfig", "mosaik.SimConfig"),
+        ("mosaik$$$$.SimConfig", "mosaik-.SimConfig"),
+    ],
+)
+def test_package_safe_name_is_correct(pkg_name, expected_name):
+    package = package_file.PackageFile(
+        filename="tests/fixtures/deprecated-pypirc",
+        comment=None,
+        metadata=pretend.stub(name=pkg_name),
+        python_version=None,
+        filetype=None,
+    )
+
+    assert package.safe_name == expected_name
+
+
 @pytest.mark.parametrize("gpg_signature", [(None), (pretend.stub())])
 def test_metadata_dictionary(gpg_signature):
     meta = pretend.stub(
@@ -264,3 +288,8 @@ def test_malformed_from_file(monkeypatch):
         package_file.PackageFile.from_filename(filename, comment=None)
 
     assert "Invalid distribution file" in err.value.args[0]
+
+
+def test_package_from_egg():
+    filename = "tests/fixtures/twine-3.3.0-py3.9.egg"
+    package_file.PackageFile.from_filename(filename, comment=None)
